pub fn update_session_status_if(
session_id: B256,
current: SessionStatus,
status: SessionStatus,
) -> Result<bool>Expand description
Atomically update a session status only when the current status matches current.
Returns true when an entry was found with the expected current status. The
registry is only rewritten when the matched entry actually changes.